@@ -1,6 +1,12 @@
+import time
 from datetime import datetime
 
 class Timer:
+    
+    def sleep(s):
+        time.sleep(s)
+        return s 
+
     def now():
         return datetime.now()
 
